@@ -60,6 +60,7 @@
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-metafile-factory.h>
 #include <libnautilus-private/nautilus-sound.h>
+#include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-volume-monitor.h>
 #include <libnautilus-private/nautilus-authn-manager.h>
@@ -122,7 +123,7 @@ create_object (PortableServer_Servant servant,
 	} else if (strcmp (iid, METAFILE_FACTORY_IID) == 0) {
 		object = BONOBO_OBJECT (nautilus_metafile_factory_get_instance ());
 	} else {
-		return CORBA_OBJECT_NIL;
+		object = CORBA_OBJECT_NIL;
 	}
 
 	return CORBA_Object_duplicate (BONOBO_OBJREF (object), ev);
@@ -141,16 +142,12 @@ nautilus_application_instance_init (NautilusApplication *application)
 	application->undo_manager = nautilus_undo_manager_new ();
 
 	/* Watch for volume mounts so we can restore open windows */
-	g_signal_connect (nautilus_volume_monitor_get (),
-			    "volume_mounted",
-			    G_CALLBACK (volume_mounted_callback),
-			    application);
+	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_mounted",
+				 G_CALLBACK (volume_mounted_callback), application, 0);
 
 	/* Watch for volume unmounts so we can close open windows */
-	g_signal_connect (nautilus_volume_monitor_get (),
-			    "volume_unmounted",
-			    G_CALLBACK (volume_unmounted_callback),
-			    application);
+	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_unmounted",
+				 G_CALLBACK (volume_unmounted_callback), application, 0);
 }
 
 NautilusApplication *
@@ -176,7 +173,7 @@ nautilus_application_destroy (BonoboObject *object)
 
 	nautilus_bookmarks_exiting ();
 	
-	bonobo_object_unref (BONOBO_OBJECT (application->undo_manager));
+	bonobo_object_unref (application->undo_manager);
 
 	EEL_CALL_PARENT (BONOBO_OBJECT_CLASS, destroy, (object));
 }
@@ -277,31 +274,6 @@ nautilus_make_uri_list_from_shell_strv (const char * const *strv)
 	return uri_list;
 }
 
-/* Find ~/.gnome-desktop/Trash and rename it to ~/.gnome-desktop/Trash.gmc
- * Only if it is a directory
- */
-static void
-migrate_gmc_trash (void)
-{
-	char *dp, *trash_dir, *dest;
-	struct stat buf;
-
-	dp = nautilus_get_desktop_directory ();
-	trash_dir = g_strconcat (dp, "/", "Trash", NULL);
-	dest = g_strconcat (dp, "/", "Trash.gmc", NULL);
-	
-	if (stat (trash_dir, &buf) == 0 && S_ISDIR (buf.st_mode)) {
-		rename (trash_dir, dest);
-#if GNOME2_CONVERSION_COMPLETE
-		gnome_metadata_rename (trash_dir, dest);
-#endif
-	}
-	
-	g_free (dp);
-	g_free (trash_dir);
-	g_free (dest);
-}
-
 static void
 migrate_old_nautilus_files (void)
 {
@@ -395,8 +367,7 @@ finish_startup (NautilusApplication *application)
 	/* initialize URI authentication manager */
 	nautilus_authentication_manager_init ();
 
-	/* Make the desktop work with gmc and old Nautilus. */
-	migrate_gmc_trash ();
+	/* Make the desktop work with old Nautilus. */
 	migrate_old_nautilus_files ();
 }
 
@@ -443,8 +414,8 @@ nautilus_application_startup (NautilusApplication *application,
 	/* Start up the factory. */
 	while (TRUE) {
 		/* Try to register the file manager view factory. */
-		result = bonobo_activation_active_server_register (
-			FACTORY_IID, BONOBO_OBJREF (application));
+		result = nautilus_bonobo_activation_register_for_display
+			(FACTORY_IID, BONOBO_OBJREF (application));
 
 		switch (result) {
 		case Bonobo_ACTIVATION_REG_SUCCESS:
@@ -664,16 +635,14 @@ nautilus_application_create_window (NautilusApplication *application)
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 	
 	window = NAUTILUS_WINDOW (gtk_widget_new (nautilus_window_get_type (),
-						  "app", G_OBJECT (application),
+						  "app", application,
 						  "app_id", "nautilus", NULL));
 	
-	g_signal_connect (window, 
-			    "delete_event", G_CALLBACK (nautilus_window_delete_event_callback),
-                    	    NULL);
+	g_signal_connect (window, "delete_event",
+			  G_CALLBACK (nautilus_window_delete_event_callback), NULL);
 
-	g_signal_connect (window,
-			    "destroy", G_CALLBACK (nautilus_application_destroyed_window),
-			    application);
+	g_signal_connect_object (window, "destroy",
+				 G_CALLBACK (nautilus_application_destroyed_window), application, 0);
 
 	nautilus_application_window_list = g_list_prepend (nautilus_application_window_list, window);
 
@@ -723,7 +692,7 @@ desktop_changed_callback (gpointer user_data)
  * presented is: ~/.nautilus/first-time-flag.
  *
  * Another alternative could be to use preferences to store this flag
- * However, there because of bug 1229 this is not yet possible.
+ * However, there because of bug 41229 this is not yet possible.
  *
  * Also, for debugging purposes, it is convenient to have just one file
  * to kill in order to test the startup druid:
@@ -744,7 +713,7 @@ need_to_show_first_time_druid (void)
 	user_directory = nautilus_get_user_directory ();
 
 	druid_flag_file_name = g_strconcat (user_directory, "/first-time-flag", NULL);
-	result = !g_file_exists (druid_flag_file_name);	
+	result = !g_file_test (druid_flag_file_name, G_FILE_TEST_EXISTS);
 	g_free (druid_flag_file_name);
 
 	/* we changed the name of the flag for version 1.0, so we should
@@ -903,12 +872,10 @@ init_session (void)
 	client = gnome_master_client ();
 
 	g_signal_connect (client, "save_yourself",
-			    (GtkSignalFunc) save_session,
-			    NULL);
+			  G_CALLBACK (save_session), NULL);
 	
 	g_signal_connect (client, "die",
-			    (GtkSignalFunc) removed_from_session,
-			    NULL);
+			  G_CALLBACK (removed_from_session), NULL);
 	
 	eel_preferences_add_callback
 		(NAUTILUS_PREFERENCES_ADD_TO_SESSION,
@@ -1043,9 +1010,8 @@ is_kdesktop_present (void)
 }
 
 static void
-nautilus_application_class_init (NautilusApplicationClass *klass)
+nautilus_application_class_init (NautilusApplicationClass *class)
 {
-	BONOBO_OBJECT_CLASS (klass)->destroy = nautilus_application_destroy;
-	
-	BONOBO_GENERIC_FACTORY_CLASS (klass)->epv.createObject = create_object;
+	BONOBO_OBJECT_CLASS (class)->destroy = nautilus_application_destroy;
+	BONOBO_GENERIC_FACTORY_CLASS (class)->epv.createObject = create_object;
 }
