@@ -39,7 +39,6 @@
 
 #include <eel/eel-background.h>
 #include <eel/eel-glib-extensions.h>
-#include <eel/eel-gobject-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
@@ -50,6 +49,7 @@
 #include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkpaned.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
@@ -84,7 +84,7 @@ struct NautilusSidebarDetails {
 	gboolean has_buttons;
 	char *uri;
 	NautilusFile *file;
-	gulong file_changed_connection;
+	guint file_changed_connection;
 	char *default_background_color;
 	char *default_background_image;
 	int selected_index;
@@ -118,7 +118,6 @@ static void     nautilus_sidebar_drag_data_received    (GtkWidget        *widget
 static void     nautilus_sidebar_read_theme            (NautilusSidebar  *sidebar);
 static void     nautilus_sidebar_size_allocate         (GtkWidget        *widget,
 							GtkAllocation    *allocation);
-static void     nautilus_sidebar_realize               (GtkWidget        *widget);
 static void     nautilus_sidebar_theme_changed         (gpointer          user_data);
 static void     nautilus_sidebar_confirm_trash_changed (gpointer          user_data);
 static void     nautilus_sidebar_update_appearance     (NautilusSidebar  *sidebar);
@@ -133,6 +132,10 @@ static void     background_metadata_changed_callback   (NautilusSidebar  *sideba
 #define SIDEBAR_MINIMUM_WIDTH 1
 #define SIDEBAR_MINIMUM_HEIGHT 400
 
+/* Some auto-updated values */
+static int      sidebar_width_auto_value = SIDEBAR_MINIMUM_WIDTH;
+static gboolean confirm_trash_auto_value = TRUE;
+
 enum {
 	LOCATION_CHANGED,
 	LAST_SIGNAL
@@ -168,9 +171,6 @@ typedef enum {
 	TABS_PART
 } SidebarPart;
 
-static gboolean confirm_trash_auto_value;
-
-
 EEL_CLASS_BOILERPLATE (NautilusSidebar, nautilus_sidebar, GTK_TYPE_EVENT_BOX)
 
 /* initializing the class object by installing the operations we override */
@@ -196,7 +196,6 @@ nautilus_sidebar_class_init (GtkObjectClass *object_klass)
 	widget_class->button_press_event  = nautilus_sidebar_press_event;
 	widget_class->button_release_event  = nautilus_sidebar_release_event;
 	widget_class->size_allocate = nautilus_sidebar_size_allocate;
-	widget_class->realize = nautilus_sidebar_realize;
 
 	/* add the "location changed" signal */
 	signals[LOCATION_CHANGED] = g_signal_new
@@ -208,9 +207,6 @@ nautilus_sidebar_class_init (GtkObjectClass *object_klass)
 		 NULL, NULL,
 		 g_cclosure_marshal_VOID__STRING,
 		 G_TYPE_NONE, 1, G_TYPE_STRING);
-
-	eel_preferences_add_auto_boolean (NAUTILUS_PREFERENCES_CONFIRM_TRASH,
-					       &confirm_trash_auto_value);
 }
 
 /* utility routine to allocate the box the holds the command buttons */
@@ -235,16 +231,30 @@ make_button_box (NautilusSidebar *sidebar)
 static void
 nautilus_sidebar_init (GtkObject *object)
 {
+	GtkWidget *widget;
+	static gboolean setup_autos = FALSE;
 	NautilusSidebar *sidebar;
-	GtkWidget* widget;
 	
 	sidebar = NAUTILUS_SIDEBAR (object);
 	widget = GTK_WIDGET (object);
 
 	sidebar->details = g_new0 (NautilusSidebarDetails, 1);
+
+	if (!setup_autos) {
+		setup_autos = TRUE;
+		eel_preferences_add_auto_integer (
+			NAUTILUS_PREFERENCES_SIDEBAR_WIDTH,
+			&sidebar_width_auto_value);
+
+		eel_preferences_add_auto_boolean (
+			NAUTILUS_PREFERENCES_CONFIRM_TRASH,
+			&confirm_trash_auto_value);
+	}
 	
-	/* set the minimum size of the sidebar */
-	gtk_widget_set_usize (widget, SIDEBAR_MINIMUM_WIDTH, SIDEBAR_MINIMUM_HEIGHT);
+	/* set the requested size of the sidebar */
+	gtk_widget_set_size_request (widget, sidebar_width_auto_value,
+				     SIDEBAR_MINIMUM_HEIGHT);
+	sidebar->details->old_width = sidebar_width_auto_value;
 
 	/* load the default background from the current theme */
 	nautilus_sidebar_read_theme(sidebar);
@@ -281,8 +291,6 @@ nautilus_sidebar_init (GtkObject *object)
 	gtk_box_pack_end (GTK_BOX (sidebar->details->container),
 			  GTK_WIDGET (sidebar->details->sidebar_tabs),
 			  FALSE, FALSE, 0);
-
-	sidebar->details->old_width = widget->allocation.width;
 	
 	/* allocate and install the panel tabs */
   	sidebar->details->notebook = GTK_NOTEBOOK (gtk_notebook_new ());
@@ -334,8 +342,6 @@ nautilus_sidebar_finalize (GObject *object)
 	sidebar = NAUTILUS_SIDEBAR (object);
 
 	if (sidebar->details->file != NULL) {
-		g_signal_handler_disconnect (sidebar->details->file, 
-					     sidebar->details->file_changed_connection);
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 		nautilus_file_unref (sidebar->details->file);
 	}
@@ -438,12 +444,12 @@ toggle_sidebar_panel (GtkWidget *widget,
 	gboolean already_on;
 
 	g_return_if_fail (GTK_IS_CHECK_MENU_ITEM (widget));
-	g_return_if_fail (NAUTILUS_IS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (widget))));
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR (g_object_get_data (G_OBJECT (widget), "user_data")));
 	g_return_if_fail (g_object_get_data (G_OBJECT (widget), "nautilus-sidebar/preference-key") != NULL);
 
 	preference_key = g_object_get_data (G_OBJECT (widget), "nautilus-sidebar/preference-key");
 
-	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (widget)));
+	sidebar = NAUTILUS_SIDEBAR (g_object_get_data (G_OBJECT (widget), "user_data"));
 
 	nautilus_sidebar_hide_active_panel_if_matches (sidebar, sidebar_iid);
 	
@@ -497,24 +503,17 @@ sidebar_for_each_sidebar_panel (const char *name,
 	/* add a check menu item */
 	menu_item = gtk_check_menu_item_new_with_label (name);
 
-	gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item), panel_visible);
 	gtk_widget_show (menu_item);
-	gtk_object_set_user_data (GTK_OBJECT (menu_item), data->sidebar);
-	gtk_menu_append (data->menu, menu_item);
-	gtk_signal_connect_full (GTK_OBJECT (menu_item),
-				 "activate",
-				 G_CALLBACK (toggle_sidebar_panel),
-				 NULL,
-				 g_strdup (iid),
-				 g_free,
-				 FALSE,
-				 FALSE);
+	g_object_set_data (G_OBJECT (menu_item), "user_data", data->sidebar);
+	gtk_menu_shell_append (GTK_MENU_SHELL (data->menu), menu_item);
+	g_signal_connect_data (menu_item, "activate",
+			       G_CALLBACK (toggle_sidebar_panel),
+			       g_strdup (iid), (GClosureNotify) g_free, 0);
 
 	g_object_set_data_full (G_OBJECT (menu_item),
 				"nautilus-sidebar/preference-key",
-				g_strdup (preference_key),
-				g_free);
+				g_strdup (preference_key), g_free);
 }
 
 /* utility routine to add a menu item for each potential sidebar panel */
@@ -567,15 +566,15 @@ nautilus_sidebar_create_context_menu (NautilusSidebar *sidebar)
 	/* add the reset background item, possibly disabled */
 	menu_item = gtk_menu_item_new_with_label (_("Reset Background"));
  	gtk_widget_show (menu_item);
-	gtk_menu_append (GTK_MENU(menu), menu_item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
         gtk_widget_set_sensitive (menu_item, has_background);
-	g_signal_connect (menu_item, "activate",
-			    G_CALLBACK (reset_background_callback), sidebar);
+	g_signal_connect_object (menu_item, "activate",
+				 G_CALLBACK (reset_background_callback), sidebar, 0);
 
 	/* add a separator */
 	menu_item = gtk_menu_item_new ();
 	gtk_widget_show (menu_item);
-	gtk_menu_append (GTK_MENU (menu), menu_item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 	
 	/* add the sidebar panels */
 	sidebar_add_panel_context_menu_items (sidebar, menu);
@@ -814,9 +813,9 @@ receive_dropped_color (NautilusSidebar *sidebar,
 
 		/* Block so we don't respond to our own metadata changes.
 		 */
-		gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-						  G_CALLBACK (background_metadata_changed_callback),
-						  sidebar);
+		g_signal_handlers_block_by_func (sidebar->details->file,
+						 G_CALLBACK (background_metadata_changed_callback),
+						 sidebar);
 						  
 		nautilus_file_set_metadata
 			(sidebar->details->file,
@@ -824,9 +823,9 @@ receive_dropped_color (NautilusSidebar *sidebar,
 			 DEFAULT_TAB_COLOR,
 			 color_spec);
 
-		gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-						    G_CALLBACK (background_metadata_changed_callback),
-						    sidebar);
+		g_signal_handlers_unblock_by_func (sidebar->details->file,
+						   G_CALLBACK (background_metadata_changed_callback),
+						   sidebar);
 		break;
 	case TITLE_TAB_PART:
 		/* color dropped on title tab */
@@ -836,9 +835,9 @@ receive_dropped_color (NautilusSidebar *sidebar,
 		
 		/* Block so we don't respond to our own metadata changes.
 		 */
-		gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-						  G_CALLBACK (background_metadata_changed_callback),
-						  sidebar);
+		g_signal_handlers_block_by_func (sidebar->details->file,
+						 G_CALLBACK (background_metadata_changed_callback),
+						 sidebar);
 
 		nautilus_file_set_metadata
 			(sidebar->details->file,
@@ -846,9 +845,9 @@ receive_dropped_color (NautilusSidebar *sidebar,
 			 DEFAULT_TAB_COLOR,
 			 color_spec);
 
-		gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-						    G_CALLBACK (background_metadata_changed_callback),
-						    sidebar);
+		g_signal_handlers_unblock_by_func (sidebar->details->file,
+						   G_CALLBACK (background_metadata_changed_callback),
+						   sidebar);
 		break;
 	case ICON_PART:
 	case BACKGROUND_PART:
@@ -939,8 +938,8 @@ nautilus_sidebar_add_panel (NautilusSidebar *sidebar, NautilusViewFrame *panel)
 
 	gtk_widget_show (label);
 	
-	g_signal_connect (panel, "view_loaded",
-			    G_CALLBACK (view_loaded_callback), sidebar);
+	g_signal_connect_object (panel, "view_loaded",
+				 G_CALLBACK (view_loaded_callback), sidebar, 0);
 	
 	gtk_notebook_append_page (GTK_NOTEBOOK (sidebar->details->notebook),
 				  GTK_WIDGET (panel), label);
@@ -1048,7 +1047,7 @@ nautilus_sidebar_activate_panel (NautilusSidebar *sidebar, int which_view)
 	gtk_widget_hide (GTK_WIDGET (sidebar->details->button_box_centerer));
 	gtk_widget_hide (GTK_WIDGET (sidebar->details->title));
 	
-	gtk_notebook_set_page (notebook, which_view);
+	gtk_notebook_set_current_page (notebook, which_view);
 	notify_current_sidebar_view (sidebar, "close", FALSE);
 }
 
@@ -1213,9 +1212,9 @@ background_settings_changed_callback (EelBackground *background, NautilusSidebar
 	
 	/* Block so we don't respond to our own metadata changes.
 	 */
-	gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-					  G_CALLBACK (background_metadata_changed_callback),
-					  sidebar);
+	g_signal_handlers_block_by_func (sidebar->details->file,
+					 G_CALLBACK (background_metadata_changed_callback),
+					 sidebar);
 
 	color = eel_background_get_color (background);
 	image = eel_background_get_image_uri (background);
@@ -1233,9 +1232,9 @@ background_settings_changed_callback (EelBackground *background, NautilusSidebar
 	g_free (color);
 	g_free (image);
 
-	gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-					    G_CALLBACK (background_metadata_changed_callback),
-					    sidebar);
+	g_signal_handlers_unblock_by_func (sidebar->details->file,
+					   G_CALLBACK (background_metadata_changed_callback),
+					   sidebar);
 }
 
 /* handle the background reset signal by writing out NULL to metadata and setting the backgrounds
@@ -1252,9 +1251,9 @@ background_reset_callback (EelBackground *background, NautilusSidebar *sidebar)
 
 	/* Block so we don't respond to our own metadata changes.
 	 */
-	gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-					  G_CALLBACK (background_metadata_changed_callback),
-					  sidebar);
+	g_signal_handlers_block_by_func (sidebar->details->file,
+					 G_CALLBACK (background_metadata_changed_callback),
+					 sidebar);
 
 	nautilus_file_set_metadata (sidebar->details->file,
 				    NAUTILUS_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
@@ -1266,9 +1265,9 @@ background_reset_callback (EelBackground *background, NautilusSidebar *sidebar)
 				    NULL,
 				    NULL);
 
-	gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-					    G_CALLBACK (background_metadata_changed_callback),
-					    sidebar);
+	g_signal_handlers_unblock_by_func (sidebar->details->file,
+					   G_CALLBACK (background_metadata_changed_callback),
+					   sidebar);
 
 	/* Force a read from the metadata to set the defaults
 	 */
@@ -1291,7 +1290,7 @@ command_button_callback (GtkWidget *button, char *id_str)
 	NautilusSidebar *sidebar;
 	GnomeVFSMimeApplication *application;
 	
-	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (button)));
+	sidebar = NAUTILUS_SIDEBAR (g_object_get_data (G_OBJECT (button), "user_data"));
 
 	application = gnome_vfs_application_registry_get_mime_application (id_str);
 
@@ -1311,7 +1310,7 @@ metadata_button_callback (GtkWidget *button, const char *command_str)
 {
 	NautilusSidebar *sidebar;
 		
-	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (button)));
+	sidebar = NAUTILUS_SIDEBAR (g_object_get_data (G_OBJECT (button), "user_data"));
 }
 
 static void
@@ -1335,7 +1334,7 @@ open_with_callback (GtkWidget *button, gpointer ignored)
 {
 	NautilusSidebar *sidebar;
 	
-	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (button)));
+	sidebar = NAUTILUS_SIDEBAR (g_object_get_data (G_OBJECT (button), "user_data"));
 	
 	g_return_if_fail (sidebar->details->file != NULL);
 
@@ -1370,13 +1369,6 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 				    FALSE, FALSE, 
 				    0);
 
-		/* FIXME bugzilla.gnome.org 42510: Security hole?
-		 * Unsafe to use a string from the MIME file as a
-		 * printf format string without first checking it over
-		 * somehow. We can do a search and replace on the "%s"
-		 * part instead, which should work.
-		 */
-
 		/* Get the local path, if there is one */
 		file_path = gnome_vfs_get_local_path_from_uri (sidebar->details->uri);
 		if (file_path == NULL) {
@@ -1384,7 +1376,7 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 		} 
 
 		temp_str = g_shell_quote (file_path);		
-		id_string = g_strdup_printf (application->id, temp_str); 		
+		id_string = eel_str_replace_substring (application->id, "%s", temp_str); 		
 		g_free (file_path);
 		g_free (temp_str);
 
@@ -1392,7 +1384,7 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 			(GTK_OBJECT (temp_button), "clicked",
 			 G_CALLBACK (command_button_callback), id_string);
 
-                gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
+                g_object_set_data (G_OBJECT (temp_button), "user_data", sidebar);
 		
 		gtk_widget_show (temp_button);
 	}
@@ -1400,8 +1392,8 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 	/* Catch-all button after all the others. */
 	temp_button = gtk_button_new_with_label (_("Open with..."));
 	g_signal_connect (temp_button, "clicked",
-			    G_CALLBACK (open_with_callback), NULL);
-	gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
+			  G_CALLBACK (open_with_callback), NULL);
+	g_object_set_data (G_OBJECT (temp_button), "user_data", sidebar);
 	gtk_widget_show (temp_button);
 	gtk_box_pack_start (GTK_BOX (sidebar->details->button_box),
 			    temp_button, FALSE, FALSE, 0);
@@ -1445,7 +1437,7 @@ add_buttons_from_metadata (NautilusSidebar *sidebar, const char *button_data)
 					eel_gtk_signal_connect_free_data 
 						(GTK_OBJECT (temp_button), "clicked",
 						 G_CALLBACK (metadata_button_callback), command_string);
-		                	gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
+		                	g_object_set_data (G_OBJECT (temp_button), "user_data", sidebar);
 					
 					gtk_widget_show (temp_button);			
 				}
@@ -1516,14 +1508,10 @@ nautilus_sidebar_update_buttons (NautilusSidebar *sidebar)
 		sidebar->details->has_buttons = TRUE;
 					
 		g_signal_connect (temp_button, "clicked",
-			G_CALLBACK (empty_trash_callback), NULL);
+				  G_CALLBACK (empty_trash_callback), NULL);
 		
-		eel_signal_connect_while_alive (G_OBJECT (nautilus_trash_monitor_get ()),
-						"trash_state_changed",
-						G_CALLBACK (nautilus_sidebar_trash_state_changed_callback),
-						temp_button,
-						G_OBJECT (temp_button));
-
+		g_signal_connect_object (nautilus_trash_monitor_get (), "trash_state_changed",
+					 G_CALLBACK (nautilus_sidebar_trash_state_changed_callback), temp_button, 0);
 	}
 	
 	/* Make buttons for each item in short list + "Open with..." catchall,
@@ -1560,14 +1548,10 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	background = eel_get_widget_background (GTK_WIDGET (sidebar));
 	if (!sidebar->details->background_connected) {
 		sidebar->details->background_connected = TRUE;
-		g_signal_connect (background,
-				    "settings_changed",
-				    G_CALLBACK (background_settings_changed_callback),
-				    sidebar);
-		g_signal_connect (background,
-				    "reset",
-				    G_CALLBACK (background_reset_callback),
-				    sidebar);
+		g_signal_connect_object (background,"settings_changed",
+					 G_CALLBACK (background_settings_changed_callback), sidebar, 0);
+		g_signal_connect_object (background, "reset",
+					 G_CALLBACK (background_reset_callback), sidebar, 0);
 	}
 	
 	/* Set up the background color and image from the metadata. */
@@ -1585,9 +1569,9 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	}
 		
 	/* Block so we don't write these settings out in response to our set calls below */
-	gtk_signal_handler_block_by_func (GTK_OBJECT (background),
-					  G_CALLBACK (background_settings_changed_callback),
-					  sidebar);
+	g_signal_handlers_block_by_func (background,
+					 G_CALLBACK (background_settings_changed_callback),
+					 sidebar);
 
 	eel_background_set_image_uri (background, background_image);
 	eel_background_set_color (background, background_color);
@@ -1607,9 +1591,9 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	nautilus_sidebar_tabs_set_color(sidebar->details->title_tab, color_spec);
 	g_free (color_spec);
 
-	gtk_signal_handler_unblock_by_func (GTK_OBJECT (background),
-					    G_CALLBACK (background_settings_changed_callback),
-					    sidebar);
+	g_signal_handlers_unblock_by_func (background,
+					   G_CALLBACK (background_settings_changed_callback),
+					   sidebar);
 }
 
 
@@ -1656,7 +1640,6 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	if (sidebar->details->file != NULL) {
 		g_signal_handler_disconnect (sidebar->details->file, 
 					     sidebar->details->file_changed_connection);
-
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 	}
 
@@ -1668,10 +1651,9 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	sidebar->details->file = file;
 	
 	sidebar->details->file_changed_connection =
-		gtk_signal_connect_object (GTK_OBJECT (sidebar->details->file),
-					   "changed",
-					   G_CALLBACK (background_metadata_changed_callback),
-					   GTK_OBJECT (sidebar));
+		g_signal_connect_object (sidebar->details->file, "changed",
+					 G_CALLBACK (background_metadata_changed_callback),
+					 sidebar, G_CONNECT_SWAPPED);
 
 	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
 	nautilus_file_monitor_add (sidebar->details->file, sidebar, attributes);
@@ -1704,7 +1686,6 @@ nautilus_sidebar_size_allocate (GtkWidget *widget,
 	EEL_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
 	
 	/* remember the size if it changed */
-	
 	if (widget->allocation.width != sidebar->details->old_width) {
 		sidebar->details->old_width = widget->allocation.width;
  		eel_preferences_set_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH,
@@ -1712,14 +1693,18 @@ nautilus_sidebar_size_allocate (GtkWidget *widget,
 	}	
 }
 
-static void
-nautilus_sidebar_realize (GtkWidget *widget)
+void
+nautilus_sidebar_setup_width (NautilusSidebar *sidebar)
 {
-	g_return_if_fail (NAUTILUS_IS_SIDEBAR (widget));
-	
-	/* Superclass does the actual realize */
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
-	
-	/* Tell X not to erase the window contents when resizing */
-	gdk_window_set_static_gravities (widget->window, TRUE);
+	GtkPaned *paned;
+
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR (sidebar));
+	g_return_if_fail (GTK_WIDGET (sidebar)->parent != NULL);
+
+	paned = GTK_PANED (GTK_WIDGET (sidebar)->parent);
+
+	/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
+	/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
+	gtk_paned_set_position (paned, sidebar_width_auto_value);
+	sidebar->details->old_width = sidebar_width_auto_value;
 }
