@@ -82,7 +82,7 @@
 #define MENU_PATH_SHOW_HIDE_SIDEBAR			"/menu/View/Show Hide Placeholder/Show Hide Sidebar"
 #define MENU_PATH_SHOW_HIDE_TOOLBAR			"/menu/View/Show Hide Placeholder/Show Hide Toolbar"
 #define MENU_PATH_SHOW_HIDE_LOCATION_BAR		"/menu/View/Show Hide Placeholder/Show Hide Location Bar"
-#define MENU_PATH_SHOW_HIDE_STATUS_BAR			"/menu/View/Show Hide Placeholder/Show Hide Status Bar"
+#define MENU_PATH_SHOW_HIDE_STATUS_BAR			"/menu/View/Show Hide Placeholder/Show Hide Statusbar"
 
 #define MENU_PATH_HISTORY_PLACEHOLDER			"/menu/Go/History Placeholder"
 
@@ -138,11 +138,11 @@ bookmark_holder_new (NautilusBookmark *bookmark,
 	new_bookmark_holder->prompt_for_removal = is_bookmarks_menu;
 
 	new_bookmark_holder->changed_handler_id = 
-		g_signal_connect_swapped (bookmark, "appearance_changed",
-					  is_bookmarks_menu
-					  ? G_CALLBACK (schedule_refresh_bookmarks_menu)
-					  : G_CALLBACK (schedule_refresh_go_menu),
-					  window);
+		g_signal_connect_object (bookmark, "appearance_changed",
+					 is_bookmarks_menu
+					 ? G_CALLBACK (schedule_refresh_bookmarks_menu)
+					 : G_CALLBACK (schedule_refresh_go_menu),
+					 window, G_CONNECT_SWAPPED);
 
 	return new_bookmark_holder;
 }
@@ -260,14 +260,6 @@ go_menu_location_callback (BonoboUIComponent *component,
 	}
 }			   
 
-static void
-file_menu_web_search_callback (BonoboUIComponent *component, 
-			       gpointer user_data, 
-			       const char *verb)
-{
-	nautilus_window_go_web_search (NAUTILUS_WINDOW (user_data));
-}
-
 static void
 stop_button_callback (BonoboUIComponent *component, 
 			       gpointer user_data, 
@@ -361,10 +353,8 @@ forget_history_if_confirmed (NautilusWindow *window)
 					 GTK_WINDOW (window));
 	g_free (prompt);					 
 	
-	g_signal_connect (dialog,
-			  "response",
-			  G_CALLBACK (forget_history_if_yes),
-			  NULL);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (forget_history_if_yes), NULL);
 	
 	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_NO);
 }
@@ -635,8 +625,11 @@ help_menu_about_nautilus_callback (BonoboUIComponent *component,
 					 NULL,
 					 translator_credits,
 					 NULL);
+		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (user_data));
 		
 		g_free (build_message);
+
+		eel_add_weak_pointer (&about);
 	}
 	
 	gtk_window_present (GTK_WINDOW (about));
@@ -1109,7 +1102,6 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Find", file_menu_find_callback),
 		BONOBO_UI_VERB ("Toggle Find Mode", toolbar_toggle_find_mode_callback),
 #endif
-		BONOBO_UI_VERB ("Go to Web Search", file_menu_web_search_callback),
 		BONOBO_UI_VERB ("Undo", edit_menu_undo_callback),
 		BONOBO_UI_VERB ("Customize", customize_callback),
 		BONOBO_UI_VERB ("Back", go_menu_back_callback),
@@ -1123,7 +1115,7 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Show Hide Sidebar", view_menu_show_hide_sidebar_callback),
 		BONOBO_UI_VERB ("Show Hide Toolbar", view_menu_show_hide_toolbar_callback),
 		BONOBO_UI_VERB ("Show Hide Location Bar", view_menu_show_hide_location_bar_callback),
-		BONOBO_UI_VERB ("Show Hide Status Bar", view_menu_show_hide_status_bar_callback),
+		BONOBO_UI_VERB ("Show Hide Statusbar", view_menu_show_hide_status_bar_callback),
 		BONOBO_UI_VERB ("Zoom In", view_menu_zoom_in_callback),
 		BONOBO_UI_VERB ("Zoom Out", view_menu_zoom_out_callback),
 		BONOBO_UI_VERB ("Zoom Normal", view_menu_zoom_normal_callback),
@@ -1158,8 +1150,8 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
         nautilus_window_update_show_hide_menu_items (window);
 
 	/* Register to catch Bonobo UI events so we can notice View As changes */
-	g_signal_connect (window->details->shell_ui, "ui_event", 
-			  G_CALLBACK (nautilus_window_handle_ui_event_callback), window);
+	g_signal_connect_object (window->details->shell_ui, "ui_event", 
+				 G_CALLBACK (nautilus_window_handle_ui_event_callback), window, 0);
 
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 	
